#
# spec file for package google-osconfig-agent
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         GoogleCloudPlatform
%global repo            osconfig
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           google-osconfig-agent
Version:        20250115.01
Release:        2.1
Summary:        Google Cloud Guest Agent
License:        Apache-2.0
Group:          System/Daemons
URL:            https://%{provider_prefix}
Source0:        %{repo}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        rpmlintrc
# PATCH-FIX-UPSTREAM - gh/golang/glog#74 - Fix vulnerability when creating log files (CVE-2024-45339)
Patch0:         CVE-2024-45339.patch
BuildRequires:  golang(API) >= 1.22.4
BuildRequires:  golang-packaging
Requires:       google-guest-configs
BuildRoot:      %{_tmppath}/%{name}-%{version}-build



%{go_nostrip}
%{go_provides}

%description
Google Cloud OSConfig Agent

%prep
%setup -q -n %{repo}-%{version}
%setup -q -D -T -a 1 -n %{repo}-%{version}
%patch -P0 -p0

%build
%goprep %{import_path}
CGO_ENABLED=0 go build -ldflags="-s -w -X main.version=%{version}-%{release}" -mod=vendor -o google_osconfig_agent

%install
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_sbindir}
install -d %{buildroot}/etc/osconfig
install -p -m 0755 google_osconfig_agent %{buildroot}%{_bindir}/google_osconfig_agent
install -d %{buildroot}%{_unitdir}
install -p -m 0644 %{name}.service %{buildroot}%{_unitdir}
for srv_name in %{buildroot}%{_unitdir}/*.service; do rc_name=$(basename -s '.service' $srv_name); ln -s service %{buildroot}%{_sbindir}/rc$rc_name; done

%pre
    %service_add_pre google-osconfig-agent.service

%preun
    %service_del_preun google-osconfig-agent.service

%post
    %service_add_post google-osconfig-agent.service

    if [ "$1" = "2" ] && ! [ -e /.buildenv ]; then
      # If the old directory exists make sure we set the file there.
      [ -e %{_sysconfdir}/osconfig ] && touch %{_sysconfdir}/osconfig/osconfig_agent_restart_required
      install -D /dev/null %{_var}/lib/google_osconfig_agent/osconfig_agent_restart_required
    fi

%postun
    %service_del_postun_without_restart google-osconfig-agent.service

%files
%defattr(0644,root,root,0755)
%doc README.md
%license LICENSE THIRD_PARTY_LICENSES
%attr(0755,root,root) %{_bindir}/*
%attr(0755,root,root) %{_sbindir}/*
%{_unitdir}/%{name}.service

%changelog
* Mon Feb 17 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add patch to fix vulnerability when creating log files
  * CVE-2024-45339.patch (bsc#1236560, CVE-2024-45339)
* Mon Jan 27 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20250115.01 (bsc#1236406, bsc#1236407)
  * Bump cloud.google.com/go/osconfig from 1.14.2 to 1.14.3 (#772)
- from version 20250115.00
  * Bump cloud.google.com/go/auth from 0.10.2 to 0.14.0 (#767)
  * Bump go.opentelemetry.io/otel from 1.32.0 to 1.33.0 (#771)
  * Bump google.golang.org/protobuf from 1.35.1 to 1.36.2 (#763)
- from version 20250114.00
  * Bump golang.org/x/time from 0.8.0 to 0.9.0 (#770)
- from version 20250113.01
  * Bump cloud.google.com/go/auth/oauth2adapt from 0.2.5 to 0.2.7 (#766)
- from version 20250113.00
  * Bump golang.org/x/net from 0.31.0 to 0.34.0 (#769)
- from version 20250110.00
  * Bump golang.org/x/crypto from 0.29.0 to 0.31.0 in the go_modules group (#760)
  * Bump cloud.google.com/go/longrunning from 0.6.2 to 0.6.3 (#744)
- from version 20241218.00
  * Scanners fixes (#720)
  * Bump cloud.google.com/go/storage from 1.46.0 to 1.47.0 (#736)
  * Bump go.opentelemetry.io/contrib/detectors/gcp from 1.29.0 to 1.32.0 (#730)
  * Bump go.opentelemetry.io/contrib/instrumentation/net/http/otelhttp (#738)
  * Bump golang.org/x/net from 0.30.0 to 0.31.0 (#731)
- from version 20241118.01
  * Bump github.com/googleapis/gax-go/v2 from 2.13.0 to 2.14.0 (#737)
- from version 20241118.00
  * move example to appropriate directory (#740)
- from version 20241115.00
  * Replace sles-15-sp3-sap old deprecated image in e2e tests (#739)
  * Bump golang.org/x/time from 0.7.0 to 0.8.0 (#734)
- from version 20241114.03
  * Bump github.com/GoogleCloudPlatform/opentelemetry-operations-go/detectors/gcp (#735)
- from version 20241114.02
  * Bump go.opentelemetry.io/contrib/instrumentation/google.golang.org/grpc/otelgrpc (#729)
- from version 20241114.01
  * Remove SLES-15-SP2-SAP from e2e tests and add the new SLES-15-SP6 (#733)
  * Bump golang.org/x/crypto from 0.28.0 to 0.29.0 (#728)
  * Bump go.opentelemetry.io/otel/sdk/metric from 1.30.0 to 1.32.0 (#727)
- from version 20241114.00
  * Add example to run exec script from the gcs bucket (#732)
  * Bump cel.dev/expr from 0.16.1 to 0.18.0 (#723)
- from version 20241112.00
  * Bump golang.org/x/oauth2 from 0.23.0 to 0.24.0 (#722)
  * Bump github.com/GoogleCloudPlatform/opentelemetry-operations-go/exporter/metric (#721)
  * Bump google.golang.org/grpc from 1.67.1 to 1.68.0 (#725)
  * Bump github.com/golang/glog from 1.2.2 to 1.2.3 (#715)
  * Bump google.golang.org/api from 0.203.0 to 0.205.0 (#716)
- from version 20241107.01
  * Bump github.com/envoyproxy/go-control-plane from 0.13.0 to 0.13.1 (#717)
  * Bump github.com/GoogleCloudPlatform/opentelemetry-operations-go/internal/resourcemapping (#718)
  * Bump cloud.google.com/go/auth from 0.10.0 to 0.10.1 (#719)
- from version 20241107.00
  * Bump cloud.google.com/go/logging from 1.11.0 to 1.12.0 (#709)
  * Bump cloud.google.com/go/iam from 1.2.1 to 1.2.2 (#710)
  * Bump cloud.google.com/go/storage from 1.43.0 to 1.46.0 (#713)
  * Bump cloud.google.com/go/osconfig from 1.14.1 to 1.14.2 (#708)
  * Bump cloud.google.com/go/auth/oauth2adapt from 0.2.4 to 0.2.5 (#712)
- from version 20241106.00
  * Update OWNERS (#714)
- from version 20241029.01
  * remove toolchain override (#706)
  * Bump go.opentelemetry.io/contrib/instrumentation/net/http/otelhttp (#701)
- from version 20241029.00
  * Bump go.opentelemetry.io/contrib/instrumentation/google.golang.org/grpc/otelgrpc (#702)
- from version 20241028.00
  * Bump cloud.google.com/go/longrunning from 0.6.0 to 0.6.2 (#705)
- from version 20241017.00
  * Add a new CloudBuild trigger config-file for auto updating the
    presubmit test container image on every new commit (#704)
- from version 20241004.00
  * Add new packagebuild presubmit that will use cloud-build (#694)
- from version 20240927.00
  * Third batch of dependencies upgrade (#690)
- Bump the golang compiler version to 1.22.4 (CVE-2024-24790)
* Wed Oct 30 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20240926.03 (bsc#1231775, bsc#1231776)
  * Revert "Bump go.opentelemetry.io/otel from 1.24.0 to 1.30.0 (#679)" (#684)
- from version 20240926.02
  * Bump go.opentelemetry.io/otel from 1.24.0 to 1.30.0 (#679)
  * another batch of depencies upgrade (#683)
- from version 20240926.01
  * aggregate dependabot changes to go.mod (#677)
  * Revert back Source package info delivery to control-plane (#673)
- from version 20240926.00
  * Update OWNERS (#676)
- from version 20240924.02
  * Upgrade grpc and it's dependencies to latest version (#672)
- from version 20240924.01
  * Implement keepalive config (#671)
- from version 20240924.00
  * Set new version of gRPC for test (#669)
- from version 20240920.00
  * Revert "bump version of the gRPC" (#667)
- from version 20240919.00
  * bump version of the gRPC (#666)
- from version 20240917.00
  * Merge pull request #665 from GoogleCloudPlatform/revert-664-update_grpc_dependency
  * Revert "Update grpc library and other dependencies. (#664)"
- from version 20240916.00
  * Update grpc library and other dependencies. (#664)
- from version 20240913.00
  * Move packagebuild presubmit to osconfig (#662)
- from version 20240912.00
  * Revert "update osconfig api to v1.13.0 & indirect dependency update" (#659)
- from version 20240822.00
  * Revert "Source package info delivery to control-plane (#639)" (#656)
- from version 20240821.00
  * Fix golang version format to fix builds. (#655)
- from version 20240814.01
  * Use gcsfuse pkg in guest-policies e2e in pkg
    update tests instead of old pkgs (#653)
  * Replace osconfig-agent-test pkg by gcsfuse in ospolicies
    tests and inventory-report tests (#652)
- from version 20240806.00
  * Disable Repository Resource test for SLES-12 (#650)
* Mon Aug  5 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20240801.00
  * Fix Debian-12 failing test by using gcsfuse pkg
  * Fix fetching gpg key unit tests (#649)
- from version 20240729.00
  * Fix for old state file on Windows (#648)
- from version 20240723.00
  * Add debugging logs for repository resource config (#646)
- from version 20240718.00
  * Fix SLES-12 SP5 RPM package-resource e2e test (#645)
- from version 20240715.01
  * Fix OSPolicies e2e tests for SLES-15 SP5 by removing
    zypper update from VMs startup script (#644)
- from version 20240715.00
  * Fix GuestPolicies e2e tests for SLES-15 SP5 by removing
    zypper update from VMs startup script (#643)
- from version 20240709.01
  * Source package info delivery to control-plane (#639)
- from version 20240709.00
  * Enable gpgcheck flag for RPM e2e tests (#638)
- from version 20240708.00
  * Update osconfig api to v1.13.0
  * Indirect dependency update (#637)
- from version 20240705.01
  * Updating Windows & Linux Chrome packages
    to fix failing e2e tests (#636)
- from version 20240705.00
  * Merge pull request #635 from Gulio/patch-1
  * Update OWNERS
- from version 20240702.02
  * Remove RHEL-7 and CentOS-7 images from e2e tests (#634)
* Tue Jul  2 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20240702.01
  * Use Debian-11 img in googet pkg build workflow (#632)
- from version 20240702.00
  * Pipeline testing 00 (#631)
- from version 20240701.00
  * update readme file (#628)
- from version 20240625.01
  * Updating yum install to support multi architecture based packages
  * Revert "Adding Architecture to the packages being installed/updated in yum repo"
- from version 20240625.00
  * Update old SLES images urls (#627)
- from version 20240620.00
  * Merge pull request #626 from GoogleCloudPlatform/yum-multiarch-fix
  * Adding Architecture to the packages being installed/updated in yum repo
- from version 20240618.01
  * Extract source_name(source_rpm) for rpm packages (#624)
- from version 20240618.00
  * update README.md file (#625)
- from version 20240615.00
  * Fix(dpkg) return onlt installed items as inventory (#623)
  * Extract source name and version for dpkg packages. (#622)
* Fri Jun 14 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20240607.00
  * Update e2e tests to use VMM team's GCP project for pkgs testing version (#621)
- from version 20240606.00
  * Disable SUSE tests to run with testing agent repo (#619)
- from version 20240604.00
  * Fix the logic of pick region for Artifact Registry function (#618)
- from version 20240603.00
  * Disable centos-stream-8 tests as it reached EOL in May 31 (#617)
- from version 20240529.00
  * Merge pull request #610 from savijatv/patch-3
  * Update cis-level1-once-a-day-policy.yaml
- from version 20240528.00
  * Merge pull request #616 from MahmoudOuka/allow-windows-e2e-tests-to-\
    install-testing-version-of-agent-from-private-artifact-registry-repos
  * Allow Windows e2e tests to pull osconfig-agent pkg from testing (private)
    repos from Artifact registry
- from version 20240527.01
  * Merge pull request #615 from MahmoudOuka/fix-SUSE-e2e-tests
  * fix SUSE e2e tests
- from version 20240527.00
  * Merge pull request #614 from MahmoudOuka/allow-apt-and-yum-\
    e2e-tests-to-pull-osconfig-agent-pkg-from-testing-repos
  * fix golint comments
  * Allow Apt & Yum e2e tests to pull osconfig-agent pkg from testing repos
- from version 20240524.03
  * Merge pull request #611 from savijatv/patch-ospolicy-samples
  * Update to the CIS OS policy samples
- from version 20240524.00
  * Merge pull request #612 from MahmoudOuka/update-apt-e2e-tests-\
    to-pull-osconfig-agent-pkg-from-new-ar-repos
  * fix golint comment
  * Update Apt e2e tests to pull osconfig-agent pkg from new AR repos instead of rapture
- from version 20240523.02
  * bump golang.org/x/crypto version (#613)
- from version 20240523.00
  * update go-cmp dependency (#604)
- from version 20240522.00
  * rollback masive dependency update (#603)
  * Bump google.golang.org/api from 0.180.0 to 0.181.0 (#596)
* Wed May 22 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20240517.00
  * Bump cloud.google.com/go/auth from 0.4.1 to 0.4.2 (#597)
- from version 20240516.01
  * Bump cloud.google.com/go/logging from 1.9.0 to 1.10.0 (#595)
  * Bump cloud.google.com/go/storage from 1.40.0 to 1.41.0 (#594)
- from version 20240516.00
  * Bump google.golang.org/grpc from 1.63.2 to 1.64.0 (#593)
* Thu May 16 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20240513.02
  * E2e tests: allow passing spesific EL version
    number to InstallOSConfigEL func (#592)
- from version 20240513.01
  * Bump google.golang.org/api from 0.179.0 to 0.180.0 (#591)
- from version 20240513.00
  * E2e tests: Fix EL version detection logic in E2E tests (#590)
  * Bump google.golang.org/api from 0.178.0 to 0.179.0 (#589)
- from version 20240510.02
  * Bump cloud.google.com/go/auth from 0.4.0 to 0.4.1 (#588)
- from version 20240510.01
  * E2e tests: use family url format instead of specific
    version URL for head test images (#587)
- from version 20240510.00
  * Fix for lock location (#586)
- from version 20240509.03
  * Bump cloud.google.com/go from 0.112.2 to 0.113.0 (#584)
- from version 20240509.02
  * Remove dependabot not needed label (#576)
- from version 20240509.01
  * Write inventory to attributes only if enabled (#486)
- from version 20240509.00
  * E2e tests: install gnupg2 and run apt update in VMs startup-scripts (#583)
  * Add a temporary e2e test image for Ubuntu to test
    the latest osconfig-agent stable version (#582)
  * Bump google.golang.org/api from 0.177.0 to 0.178.0 (#578)
  * Bump github.com/googleapis/gax-go/v2 from 2.12.3 to 2.12.4 (#579)
  * Bump cloud.google.com/go/iam from 1.1.7 to 1.1.8 (#577)
  * Bump cloud.google.com/go/auth from 0.3.0 to 0.4.0 (#580)
  * Bump go.opentelemetry.io/contrib/instrumentation/google.golang.org/grpc/otelgrpc (#581)
  * Bump golang.org/x/net from 0.24.0 to 0.25.0 (#575)
  * Bump cloud.google.com/go/osconfig from 1.12.6 to 1.12.7 (#573)
  * Bump go.opentelemetry.io/contrib/instrumentation/net/http/otelhttp (#574)
  * Bump cloud.google.com/go/longrunning from 0.5.6 to 0.5.7 (#571)
- from version 20240508.08
  * Bump github.com/golang/glog from 1.2.0 to 1.2.1 (#572)
- from version 20240508.07
  * Bump golang.org/x/text from 0.14.0 to 0.15.0 (#565)
- from version 20240508.06
  * Bump golang.org/x/oauth2 from 0.19.0 to 0.20.0 (#566)
  * Bump golang.org/x/sys from 0.19.0 to 0.20.0 (#564)
- from version 20240508.05
  * Bump go.opentelemetry.io/otel/trace from 1.24.0 to 1.26.0 (#563)
- from version 20240508.04
  * Bump google.golang.org/protobuf from 1.34.0 to 1.34.1 (#567)
  * Using the default reviewer set for PR approvals (#570)
- from version 20240508.03
  * Adding advanced CodeQL settings to scan on PRs (#569)
- from version 20240508.02
  * Update Debian-12 package build workflow to use debian-cloud project (#568)
- from version 20240508.01
  * Dependabot dependency updates (#562)
- from version 20240508.00
  * Revert "Initial configuration of the dependabot
    for the direct and indirect d…" (#561)
  * Initial configuration of the dependabot for the
    direct and indirect dependency scanning (#560)
- from version 20240507.00
  * Fix Debian-12 package build workflow typo (#559)
- from version 20240506.00
  * Use signed-by keyring approach for apt repos in Debian 12+ and Ubuntu 24+ (#558)
- from version 20240501.03
  * Logrus dependency update (#557)
- from version 20240501.02
  * Updating dependencies and respective checksums (#556)
- from version 20240501.01
  * Update go.mod (#554)
- from version 20240501.00
  * Bump golang.org/x/net from 0.17.0 to 0.23.0 (#542)
- from version 20240430.01
  * Remove SBOM generation logic from package build workflows (#553)
- from version 20240425.00
  * Fix e2e tests for exec-output size limit (#552)
- from version 20240424.00
  * Disabled some images which are either past EoL or broken (#549)
- from version 20240423.01
  * Copy packagebuild folder from guest-test-infra repo to osconfig repo (#545)
  * OS Config windows state file location changed (#544)
- from version 20240423.00
  * Removed debian-10 from e2e tests (#548)
- from version 20240422.00
  * Merge pull request #541 from GoogleCloudPlatform/michaljankowiak-patch-1
  * Update OWNERS
- from version 20240409.00
  * Bump output size limit to 500KB (#538)
* Fri Mar 22 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20240320.00 (bsc#1221900, bsc#1221901)
  * Enable OSConfig agent to read GPG keys files with multiple entities (#537)
- from version 20240314.00
  * Update OWNERS file to replace mahmoudn GitHub
    username by personal email GitHub username (#534)
- from version 20240313.01
  * Bump google.golang.org/protobuf from 1.30.0 to 1.33.0 in /e2e_tests (#535)
- from version 20240313.00
  * Adds a console and gcloud example policies (#533)
- from version 20240228.00
  * GuestPolicies e2e: Remove ed package if exist for zypper
    startup_script in recipe-steps tests (#532)
- from version 20240126.00
  * Fix Enterprise Linux Recipe-Steps tests to install
    info dependency package in the startup-script (#530)
- from version 20240125.01
  * Fix SUSE pkg-update and pkg-no-update e2e tests (#529)
- from version 20240125.00
  * Fix zypper patch info parser to consider conflicts-pkgs float versions (#528)
- from version 20240123.01
  * Fix SUSE package update e2e tests to use another existing package (#527)
- from version 20240123.00
  * Update cis-exclude-check-once-a-day.yaml (#526)
* Thu Jan  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20231219.00
  * Bump golang.org/x/crypto from 0.14.0 to 0.17.0 (#524)
- from version 20231207.01
  * Some change to create an agent release (#523)
- from version 20231207.00
  * Some change to create an agent release (#522)
- from version 20231205.00
  * Some change to create an agent release (#521)
- from version 20231130.02
  * Merge pull request #519 from Gulio/just-release
  * Merge branch 'master' into just-release
  * Some change to create an agent release
  * Some change to create an agent release
- from version 20231130.00
  * Some change to create an agent release (#518)
- from version 20231129.00
  * Fix parse yum updates to consider the packages under
    installing-dependencies keyword (#502)
  * Update feature names in the README file (#517)
- from version 20231128.00
  * Updating owners (#508)
- from version 20231127.00
  * Move OS policy CIS examples under the console folder (#514)
- from version 20231123.01
  * Adds three more OS Policy examples to CIS folder (#509)
  * Added ekrementeskii and MahmoudNada0 to OWNERS (#505)
- from version 20231123.00
  * docs(osconfig):add OS policy examples for CIS scanning (#503)
- from version 20231121.02
  * Added SCODE to Windows error description (#504)
- from version 20231121.01
  * Update OWNERS (#501)
  * Update go version to 1.21 (#507)
- from version 20231121.00
  * Call fqdn (#481)
- from version 20231116.00
  * Removing obsolete MS Windows 2019 images (#500)
- from version 20231107.00
  * Update owners. (#498)
- from version 20231103.02
  * Increasing test timeouts (#499)
  * Update OWNERS (#497)
- from version 20231103.01
  * Bump google.golang.org/grpc from 1.53.0 to 1.56.3 in /e2e_tests (#493)
  * Bump google.golang.org/grpc from 1.53.0 to 1.56.3 (#494)
- from version 20231103.00
  * Removing deprecated Win for containers OSs (#496)
- from version 20231027.00
  * Shortening the reported image names (#495)
- from version 20231025.00
  * Merge pull request #492 from GoogleCloudPlatform/michaljankowiak-patch-1
  * Merge branch 'master' into michaljankowiak-patch-1
  * Fixing name changes
  * Fixing rename issue
  * Fixed formatting
  * Fixed formatting
  * Fixing formatting
  * Removing support for RHEL 6, adding RHEL 9
  * Removing support for RHEL 6, adding for RHEL 9
  * Removing support for RHEL 6 and adding for RHEL 9
  * Removing step needed for RHEL 6
  * Fixing build issues
  * Removing nonexistent images and adding new ones
- from version 20231024.00
  * Removing obsolete OS images and adding new ones (#491)
- from version 20231020.00
  * Change debug messages when parsing zypper patch output (#490)
- from version 20231013.00
  * Bump golang.org/x/net from 0.7.0 to 0.17.0 (#489)
- from version 20231010.00
  * Revert "Added [main] section with gpgcheck to
    the agent-managed repo file (#484)" (#488)
- from version 20231003.00
  * Bump google.golang.org/grpc from 1.42.0 to 1.53.0 in /e2e_tests (#478)
- from version 20230920.00
  * Update OWNERS (#485)
- from version 20230912.00
  * Added [main] section with gpgcheck to the agent-managed repo file (#484)
  * Migrate empty interface to any (#483)
* Fri Oct 20 2023 Robert Schweikert <rjschwei@suse.com>
- Bump the golang compiler version to 1.21 (bsc#1216546)
* Thu Aug 31 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20230829.00
  * Added burov, dowgird, paulinakania and Gulio to OWNERS (#482)
* Fri Jul  7 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20230706.02 (bsc#1212418, bsc#1212759)
  * Update go version in go.mod (#479)
- from version 20230706.01
  * Fix condition to have 10 attempts rather than 11. (#477)
- from version 20230706.00
  * Remove tests for Ubuntu 18.04 (EOL) (#476)
- from version 20230605.00
  * Update old SLES images paths (#475)
- from version 20230602.00
  * Adding what exit codes mean for OS Config policy (#474)
- from version 20230504.00
  * Set DEBIAN_FRONTEND=noninteractive for apt-get (#472)
- from version 20230403.00
  * Disable repos clean-up (#471)
- from version 20230330.00
  * Revert "Call FQDN (#454)" (#470)
- from version 20230327.00
  * support new format of zypper patch (#469)
  * Fix comparing exec.Cmd in mock on Go1.20
- from version 20230316.00
  * Remove old images from e2e tests image list
- from version 20230227.01
  * Update dependencies (#466)
- from version 20230227.00
  * Bump golang.org/x/sys from 0.0.0-20210923061019-b8560ed6a9b7 to 0.1.0 (#463)
* Mon Feb 27 2023 Robert Schweikert <rjschwei@suse.com>
- Bump go API version to 1.18 (bsc#1208723)
  + Address CVE-2021-38297 and CVE-2022-23806
* Mon Feb 27 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20230222.00
  * Remove Debian 9 from e2e tests image list (#460)
- from version 20230217.00
  * Update OWNERS (#458)
- from version 20230208.00
  * Fix the error in the `copy_file_from_bucket.yaml` example. (#456)
- from version 20230202.00
  * Update owners file. (#455)
- from version 20230123.00
  * Call FQDN (#454)
* Wed Jan 18 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20221214.00
  * Close clients that are not passed anywhere (#450)
* Fri Oct 21 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20221013.01
  * Don't print raw pointer data. (#446)
- from version 20221013.00
  * Delete yum transaction files if created. (#445)
* Mon Oct 10 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20220829.00
  * Fix exclude packages field processing (#440)
- from version 20220824.00
  * Check for exclusive patches. (#442)
* Wed Sep  7 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Use install command in %%post section to create state file (bsc#1202826)
- Remove useless creation of state file directory in /var/lib
* Mon Aug 15 2022 Dirk Müller <dmueller@suse.com>
- avoid bashim in post install scripts (bsc#1195391)
* Wed Aug  3 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20220801.00 (bsc#1202100, bsc#1202101)
  * update OWNERS (#438)
  * Close client when RegisterAgent fails. (#436)
- from version 20220714.00
  * Add timeouts for pip/gem updates. (#433)
- from version 20220623.00
  * upgrade to golang 1.16 and override deb build settings for compatibility (#432)
- from version 20220606.00
  * new example policy to ensure sshd is running on windows VMs (#430)
- from version 20220531.00
  * Add default timeout for pip and gem list commands (#429)
- Don't restart daemon on package upgrade, create a state file instead (bsc#1194319)
* Thu Mar 17 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20220314.01
  * Support COS on arm64 (#426)
- from version 20220314.00
  * Fix previous PR: exec.CommandContext cannot be reused (#425)
- from version 20220304.00
  * Update the error message when an exec task is run on Windows
    without an interpreter (#423)
  * Fix string that apt-get returns when requiring downgrade (#422)
  * e2e_tests: fix patch test rerun (#421)
  * Add --allow-downgrades flag to apt-get calls when it
    fails because of wanting to downgrade a package (#418)
  * Create e2e test that runs apt-get in a state that makes
    it downgrade a package (#420)
  * e2e_tests: update OS targets, adjust retries (#419)
  * Create change_group.yaml (#416)
- from version 20220215.00
  * Add regex support to package exclusion in OS Patch (#415)
* Mon Feb 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20220209.00 (bsc#1195437, bsc#1195438)
  * Update licences, remove deprecated centos-8 tests (#414)
* Tue Feb  8 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20220204.00
  * Add DisableLocalLogging option (#413)
- from version 20220107.00
  * OS assignment example: Copy file from bucket
* Tue Nov 30 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20211117.00 (bsc#1193257, bsc#1193258)
  * Add retry logic for RegisterAgent (#404)
- from version 20211111.01
  * e2e_test: drop ubuntu 1604 image as its EOL (#403)
- from version 20211111.00
  * e2e_test: move to V1 api for OSPolicies (#397)
- from version 20211102.00
  * Fix context logging and fix label names (#400)
- from version 20211028.00
  * Add cloudops example for gcloud (#399)
* Fri Oct 22 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20211021.00
  * Added patch report logging for Zypper. (#395)
- from version 20211012.00
  * Replace deprecated instance filters with the new filters (#394)
- from version 20211006.00
  * Added patch report log messages for Yum and Apt (#392)
- from version 20210930.00
  * Config: Add package info caching (#391)
- from version 20210928.00
  * Fixed the runWithPty function to set ctty to child's filedesc (#389)
- from version 20210927.00
  * e2e_tests: fix a test output mismatch (#390)
- from version 20210924.00
  * Fix some e2e test failures (#388)
- from version 20210923.02
  * Correctly check for folder existance in package upgrade (#387)
- from version 20210923.01
  * ReportInventory: Fix bug in deb/rpm inventory, reduce calls to append (#386)
- from version 20210923.00
  * Deprecate old config directory in favor of new cache directory (#385)
- from version 20210922.02
  * Fix rpm/deb package formating for inventory reporting (#384)
- from version 20210922.01
  * Add centos stream rocky linux and available package tests (#383)
- from version 20210922.00
  * Add more info logs, actually cleanup unmanaged repos (#382)
- from version 20210901.00
  * Add E2E tests for Windows Application (#379)
  * Return lower-case package name (#377)
  * Update Terraform scripts for multi-project deployments tutorial. (#378)
- from version 20210811.00
  * Support Windows Application Inventory (#371)
- from version 20210723.00
  * Send basic inventory with RegisterAgent (#373)
- from version 20210722.1
  * e2e_tests: move to manually generated osconfig library (#372)
- from version 20210722.00
  * Create OWNERS file for examples directory (#368)
- from version 20210719.00
  * Update Zypper patch info parsing (#370)
* Tue Jul 27 2021 Bernhard Wiedemann <bwiedemann@suse.com>
- Build with go1.15 for reproducible build results (boo#1102408)
* Mon Jul 19 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20210712.1
  * Skip getting patch info when no patches are found. (#369)
- from version 20210712.00
  * Add Terraform scripts for multi-project deployments (#367)
- from version 20210709.00
  * Add examples/Terraform directory. (#366)
- from version 20210707.00
  * Fix bug in printing packages to update,
    return error for zypper patch (#365)
- from version 20210629.00
  * Add CloudOps examples for CentOS (#364)
* Wed Jun 23 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20210621.00
  * chore: Fixing a comment. (#363)
- from version 20210617.00
  * Use exec.CommandContext so that canceling the context also
    kills any running processes (#362)
- from version 20210608.1
  * e2e_tests: point to official osconfig client library (#359)
- from version 20210608.00
  * e2e_tests: deflake tests (#358)
- from version 20210607.00
  * Fix build on some architectures (#357)
- from version 20210603.00
  * Create win-validation-powershell.yaml (#356)
- from version 20210602.00
  * Agent efficiency improvements/bugfixes/logging updates (#355)
  * e2e_tests: add tests for ExecResource output (#354)
- from version 20210525.00
  * Run fieldalignment on all structs (#353)
- from version 20210521.00
  * Config Task: add error message and ExecResource output recording (#350)
  * e2e_tests: remove Windows server 1909 and add server 20h2 (#352)
  * Added a method for logging structured data (#349)
* Tue May 11 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20210506.00 (bsc#1185848, bsc#1185849)
  * Add more os policy assignment examples (#348)
  * e2e_tests: enable stable tests for OSPolicies (#347)
  * Align start and end task logs (#346)
  * ConfigTask: add additional info logs (#345)
  * e2e_tests: add validation tests (#344)
  * Config Task: make sure agent respects policy mode (#343)
  * update
  * e2e_tests: readd retries to OSPolicies
  * Set minWaitDuration as a string instead of object (#341)
  * e2e_tests: Fix a few SUSE tests (#339)
  * Remove pre-release flag from config (#340)
  * e2e_tests: fixup OSPolicy tests (#338)
  * e2e_tests: unlock mutex for CreatePolicies as soon as create finishes (#337)
  * e2e_tests: Don't retry failed OSPolicy tests, fix msi test (#336)
  * Examples for os policy assignments (#334)
  * e2e_tests: increase the deadline for OSPolicy tests and only start after a zone has been secured (#335)
  * Fix panic when installing MSI (#332)
  * e2e_tests: Add test cases of installing dbe, rpm and msi packages (#333)
  * e2e_tests: add more logging
  * e2e_tests: (#330)
  * e2e_test: Add timouts to OSPolicy tests so we don't wait forever (#329)
  * Create top level directories for gcloud and console for os policy assignment examples (#328)
  * e2e_tests: Move api from an internal directory (#327)
  * Make sure we use the same test name for reruns (#326)
  * Add CONFIG_V1 capability (#325)
  * e2e_tests: reduce size of instances, use pd-balanced, rerun failed tests once (#324)
  * Only report installed packages for dpkg (#322)
  * e2e_tests: fix windows package and repository tests (#323)
  * Add top level directories for os policy examples (#321)
  * e2e_tests: move to using inventory api for inventory reporting (#320)
  * e2e_tests: add ExecResource tests (#319)
  * ExecResource: make sure we set permissions correctly for downloaded files (#318)
  * Config task: only run post check on resources that have already been evaluated (#317)
  * e2e_test: reorganize OSPolicy tests to be per Resource type (#316)
  * Set custom user agent (#299)
  * e2e_tests: check InstanceOSPoliciesCompliance for each test case, add LocalPath FileResource test (#314)
  * PackageResource: make sure to run AptUpdate prior to package install (#315)
  * Fix bugs/add more logging for OSPolicies (#313)
  * Change metadata http client to ignore http proxies (#312)
  * e2e_test: add tests for FileResource (#311)
  * Add task_type context logging (#310)
  * Fix e2e_test typo (#309)
  * Fix e2e_tests (#308)
  * Disable OSPolicies by default since it is an unreleased feature (#307)
  * e2e_tests: Add more OSPolicies package and repo tests (#306)
  * Do not enforce repo_gpgcheck in guestpolicies (#305)
  * Gather inventory 3-5min after agent start (#303)
  * e2e_tests: add OSPolicies tests for package install (#302)
  * Add helpful error log if a service account is missing (#304)
  * OSPolicies: correct apt repo extension, remove yum/zypper gpgcheck override (#301)
  * Update cos library to parse new version of packages file (#300)
  * config_task: Rework config step logic (#296)
  * e2e_test: enable serial logs in cos to support ReportInventory test (#297)
* Wed Mar 31 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20210316.00 (bsc#1183414, bsc#1183415)
  * ExecResource: fix bug in return code handling (#295)
  * Fix ExecResource permissions, add logs to fetcher (#294)
  * e2e_tests: Fix ubuntu proposed family (#293)
  * e2e_tests: add proposed debian images to head tests (#292)
  * Fix exec_resource for config task, add minimal unit test (#291)
  * Change util.WriteFile to AtomicWriteFileStream (#289)
  * Merge development branch into master (#288)
  * Create util.TempFile to work nicely with Windows (#287)
  * Fix copy step write (#286)
  * Fix error on linux lock (#285)
  * Ensure we cleanup on error in AtomicWrite (#284)
  * Make writes atomic, add unused "allowDowngrades" option
    to apt, fix a few recipe issues (#283)
  * update reviewers (#282)
  * update apt package lists before running installs (#281)
  * Simplify build tags for COS package (#280)
* Tue Jan 12 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20210112.00
  * Fix builds for ppc and s390x (#274)
  * Minor updates to tests and additional debug logging (#272)
  * Add Ubuntu 2004 to tests (#271)
  * Make sure we stop tickers (#270)
  * Drop Windows 1903 and CentOS 6 from tests (#269)
  * Pin el6 tests to last published image as it is EOL (#267)
  * support cos (#266)
* Tue Nov 24 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20201117.00 (bsc#1179031, bsc#1179032)
  * Ignore Unavailable erros on stream receive (#260)
  * Update test Windows images (#259)
  * update ReportInventory e2e test regexes (#255)
  * Don't return on a windows update error (#254)
  * use retryutil for ReportInventory calls (#253)
  * add additional debug logging for ReportInventory request payload for e2e tests (#252)
  * stop logging instance identity token as part of ReportInventory request and remove
    feature-flag setting in OSInventoryReporting e2e tests (#251)
  * complete ExecTask as no-op when the ExecStepConfig doesn't match the OS (#250)
  * Add software recipe tests for COS (#249)
  * remove feature flag for inventory reporting (#243)
  * Force yum to never colorize output (#247)
  * Add sleep after Unavailable errors for agentendpoint (#241)
  * Ensure we record epoch for rpm packages (#242)
  * Make inventory WUAUpdates call spawn a new process,
    retry on metadata unmarshal error (#239)
  * add debug logging for report inventory response (#240)
  * add initial e2e tests for inventory reporting (#237)
  * Report installed packages on COS (#236)
* Thu Oct  8 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 20200929.00
  * Merge inventory feature from development (#235)
  * Set full version during Windows build (#234)
- Remove Provides/Obsoletes for google-compute-engine-init
* Tue Sep 15 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build (bsc#1176427, bsc#1178249, jsc#ECO-2702, jsc#PM-2203)
  + Version 20200908.00
